This function performs the cross-multiplication necessary
for prepping datasets to be used in MRFcov_spatial models.
prep_MRF_covariates_spatial(data, n_nodes, coords)Dataframe of the prepped response and covariate variables necessary for
input in MRFcov_spatial models
Dataframe. The input data where the n_nodes
left-most variables are outcome variables to be represented by nodes in the graph
Integer. The index of the last column in data which is represented by a node in the final graph. Columns with index greater than n_nodes are taken as covariates. Default is the number of columns in data, corresponding to no additional covariates
A two-column dataframe (with nrow(coords) == nrow(data))
representing the spatial coordinates of each observation in data. Ideally, these
coordinates will represent Latitude and Longitude GPS points for each observation. The coordinates
are used to create smoothed Gaussian Process spatial regression splines via
smooth.construct2.
Here, the basis dimension of the smoothed term
is chosen based on the number of unique GPS coordinates in coords.
If this number is less than 100, then this number is used. If the number of
unique coordiantes is more than 100, a value of 100 is used
(this parameter needs to be large in order to ensure enough degrees of freedom
for estimating 'wiggliness' of the smooth term; see
choose.k for details).
Observations of nodes (species) in data are prepped for
MRFcov_spatial analysis by multiplication. This function is useful if
users wish to prep the spatial splines beforehand and split the
data manually for out-of-sample cross-validation. To do so,
prep the splines here and set prep_splines = FALSE in MRFcov_spatial